@@ -10,7 +10,7 @@ use re '/aa';
 use Carp;
 use Errno;
 
-our $VERSION = '1.00_06';
+our $VERSION = '1.00_07';
 our @ISA = qw(Exporter);
 our @EXPORT = qw(BACKUP_NONE
                  BACKUP_SINGLE
@@ -139,6 +139,7 @@ sub backup_copy_internal {
 	or return _backup_copy_error($error,
 			 "failed to make a temporary copy of $file_name: $!");
     close $fh;
+    
     my $backup_name = rename_backup($tempname, $backup_stub, $num, $error);
     unless ($backup_name) {
 	unlink($tempname) or carp("can't unlink $tempname: $!");
@@ -218,8 +219,11 @@ sub rename_backup_win32 {
 	$backup_name = "$backup_stub.~$num~";
 	last if MoveFile($tempfilename, $backup_name);
 	unless ($!{EEXIST}) {
+	    my $er = &Errno::EEXIST;
+	    my $er0 = $!+0;
+	    my $er1 = $^E+0;
 	    return _backup_copy_error($error,
-			  "can't rename $tempfilename to $backup_name: $^E");
+			  "can't rename $tempfilename to $backup_name: er=$er, er0=$er0, er1=$er1, text: $^E");
 	}
 	++$num;
     }
